/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#pragma once

#include <QList>
#include <QMap>
#include <QString>

namespace ARPStatesList
{

// SMA states
enum class State : uint8_t
{
    INIT = 0,
    INIT_ERROR,
    INIT_DONE,
    INSERT_INFO,
    ARMED,
    ARMED_NF,
    TEST,
    TEST_NF,
    CALIBRATE,
    FIX_ANTENNAS,
    FIX_ROCKET,
    FIX_ROCKET_NF,
    ARM_READY,
    ACTIVE,
    ACTIVE_NF,
    CONFIG,
    FEEDBACK,
    NO_FEEDBACK,
    INVALID,
};

// Groundstation labels
static const QList<QString> statesLabels{
    "INIT", "INIT ERROR", "INIT DONE",    "INSERT\nINFO", "ARM READY", "ARMED",
    "TEST", "CALIBRATE",  "FIX ANTENNAS", "FIX ROCKET",   "ACTIVE",
};

// Map from ARP states to groundstation labels
static const QMap<State, int> statesIndexes{
    {State::INVALID, -1},      {State::CONFIG, -1},
    {State::FEEDBACK, -1},     {State::NO_FEEDBACK, -1},
    {State::INIT, 0},          {State::INIT_ERROR, 1},
    {State::INIT_DONE, 2},     {State::INSERT_INFO, 3},
    {State::ARM_READY, 4},     {State::ARMED, 5},
    {State::ARMED_NF, 5},      {State::TEST, 6},
    {State::TEST_NF, 6},       {State::CALIBRATE, 7},
    {State::FIX_ANTENNAS, 8},  {State::FIX_ROCKET, 9},
    {State::FIX_ROCKET_NF, 9}, {State::ACTIVE, 10},
    {State::ACTIVE_NF, 10}};

}  // namespace ARPStatesList
