/*
 * This file is part of Skyward Hub.
 *
 * Skyward Hub is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * Skyward Hub is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * Skyward Hub. If not, see <https://www.gnu.org/licenses/>.
 *
 */

#include "SerialPort.h"

#include <QSerialPortInfo>

SerialPort::SerialPort(QObject *parent) : serial(parent)
{
    QObject::connect(&serial, &QSerialPort::readyRead, this,
                     &SerialPort::onReadyRead);
}

bool SerialPort::open(QString portName, int baudRate)
{
    QSerialPortInfo port(portName);
    serial.setPort(port);
    serial.setBaudRate(baudRate);
    serial.setDataBits(QSerialPort::Data8);
    serial.setParity(QSerialPort::NoParity);
    serial.setStopBits(QSerialPort::OneStop);

    if (!serial.open(QIODevice::ReadWrite))
        return false;

    return true;
}

void SerialPort::close() { serial.close(); }

bool SerialPort::isOpen() { return serial.isOpen(); }

void SerialPort::writeBytes(const char *data, qsizetype len)
{
    serial.write(data, len);
    serial.flush();
}

void SerialPort::onReadyRead()
{
    auto data = serial.readAll();
    emit bytesReceived(data.data(), data.size());
}